require "swagger/template/tasks/reader"

module Swagger
  module Template
    class Endpoint
      attr_reader :path, :verb, :summary, :full_path, :classes, :filename,
                  :parameters, :dirname, :snakecases

      def initialize(spec, path, verb)
        @spec = spec
        @path = path
        @verb = verb
        extract_summary
        extract_full_path
        determine_classes
        determine_snakecases
        determine_filename
        determine_dirname
        determine_required_parameters
      end

      def to_h
        {
          verb: verb,
          path: path,
          summary: summary,
          full_path: full_path,
          classes: classes,
          filename: filename,
          dirname: dirname,
          parameters: parameters
        }
      end

      private

      def extract_summary
        @summary = @spec['paths'][path][verb]['summary']
      end

      def extract_full_path
        @full_path =  "#{@spec['basePath']}#{path}"
      end

      def determine_classes
        @classes = path.split('/').drop(1).map do |chunk|
          chunk.split('-').map(&:capitalize).join('')
        end
      end

      def determine_snakecases
        @snakecases = path.split('/').drop(1).map do |chunk|
          chunk.gsub('-', '_')
        end
      end

      def determine_filename
        @filename = path.split('/').drop(1).map do |chunk|
          chunk.gsub('-', '_')
        end.join('/')
      end

      def determine_dirname
        @dirname = filename.split('/').reverse.drop(1).reverse.join('/')
      end

      def determine_required_parameters
        @parameters = @spec['paths'][path][verb]['parameters'].select do |param|
          param['required']
        end
      end
    end
  end
end
