require "awesome_print"
require "json"
require "swagger/template/tasks/reader"
require "swagger/template/tasks/writer"

module Swagger
  module Template
    class Tasks
      def initialize(options = {})
        @swagger_path = options[:swagger_path]
        @templates_path = options[:templates_path]
        @examples = JSON.parse(File.read(options[:examples]))
        @output_path = options[:output_path]
        @language = options[:language]
        @root_entity = options[:root_entity]
      end

      def list
        endpoints = Swagger::Template::Tasks::Reader.new(@swagger_path).read
        endpoints.each do |endpoint|
          ap endpoint.to_h
        end
      end

      def generate
        endpoints = Swagger::Template::Tasks::Reader.new(@swagger_path).read
        Swagger::Template::Tasks::Writer.new(
            endpoints: endpoints,
            templates_path: @templates_path,
            output_path: @output_path,
            root_entity: @root_entity,
            root_entity_class: @root_entity.split('_').map(&:capitalize).join,
            language: @language,
            examples: @examples
          ).write
      end
    end
  end
end
